/*
 * Copyright (c) 2002-2009 syntevo GmbH. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of syntevo GmbH nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.syntevo.q.gui.layout;

/**
 * @author Thomas Singer
 */
public final class TableGridConstraints {

	// Fields =================================================================

	private final int row;
	private final int column;
	private final int height;
	private final int width;
	private final boolean stickTop;
	private final boolean stickBottom;
	private final boolean stickLeft;
	private final boolean stickRight;

	// Setup ==================================================================

	public TableGridConstraints(int row, int column, int height, int width,
	                            boolean stickTop, boolean stickLeft, boolean stickBottom, boolean stickRight) {
		if (row < 0) {
			throw new IllegalArgumentException("row must be positive");
		}
		if (column < 0) {
			throw new IllegalArgumentException("column must be positive");
		}
		if (height < 1) {
			throw new IllegalArgumentException("height must be non-zero positive");
		}
		if (width < 1) {
			throw new IllegalArgumentException("width must be non-zero positive");
		}

		this.row = row;
		this.column = column;
		this.height = height;
		this.width = width;
		this.stickTop = stickTop;
		this.stickLeft = stickLeft;
		this.stickBottom = stickBottom;
		this.stickRight = stickRight;
	}

	// Accessing ==============================================================

	public int getRow() {
		return row;
	}

	public int getColumn() {
		return column;
	}

	public int getHeight() {
		return height;
	}

	public int getWidth() {
		return width;
	}

	public boolean isStickTop() {
		return stickTop;
	}

	public boolean isStickBottom() {
		return stickBottom;
	}

	public boolean isStickLeft() {
		return stickLeft;
	}

	public boolean isStickRight() {
		return stickRight;
	}
}

