package com.syntevo.plugin.jira.commit.messagesource;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.util.List;
import javax.swing.*;

import com.syntevo.openapi.gui.*;
import com.syntevo.openapi.gui.dialog.*;
import com.syntevo.openapi.gui.table.*;
import com.syntevo.plugin.jira.transport.*;

/**
 * @author syntevo GmbH
 */
final class JiraCommitMessageSourceDialog extends AbstractOkCancelDialog {

	// Fields =================================================================

	private final JiraIssueLoader issueLoader;
	private final JiraQueryConfiguration queryConfiguration;
	private final List<JiraIssue> initialIssues;
	private final GuiComponentFactory componentFactory;

	private SortedTable<JiraIssue> table;
	private JComponent component;

	// Setup ==================================================================

	public JiraCommitMessageSourceDialog(List<JiraIssue> initialIssues, GuiComponentFactory componentFactory, JiraIssueLoader issueLoader, JiraQueryConfiguration queryConfiguration) {
		this.initialIssues = initialIssues;
		this.componentFactory = componentFactory;
		this.issueLoader = issueLoader;
		this.queryConfiguration = queryConfiguration;
	}

	// Implemented ============================================================

	public String getTitle() {
		return "Select JIRA Issue";
	}

	public JComponent createComponent(Container parent) {
		table = componentFactory.createTable(Arrays.asList(new JiraIssueKeyTableColumn(), new JiraIssueSummaryTableColumn(), new JiraIssueStatusTableColumn()), parent);
		component = table.createComponent(new Dimension(800, 600));

		table.addDoubleClickListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				performOk();
			}
		});

		setIssues(initialIssues);
		return component;
	}

	public void validate() throws DialogValidationFailedException {
		if (table.getSelection().isEmpty()) {
			throw new DialogValidationFailedException("Please select one or more issue.", component);
		}
	}

	@Override
	public JButton initButtonPanel(ButtonPanel buttonPanel) {
		buttonPanel.addButton(new ButtonAction("Refresh", BUTTON_TYPE_OTHER) {
			public void performAction() {
				issueLoader.load(queryConfiguration, true);
			}
		});
		return super.initButtonPanel(buttonPanel);
	}

	// Accessing ==============================================================

	public String getCommitMessage() {
		final List selection = table.getSelection();
		//noinspection unchecked
		return createCommitMessage(selection);
	}
	
	public void setIssues(final List<JiraIssue> issues) {
		final List selection = table.getSelection();
		table.setRows(issues);
		table.setSelection(selection);
	}

	// Utils ==================================================================

	private static String createCommitMessage(List<JiraIssue> issues) {
		final StringBuffer message = new StringBuffer();
		for (Iterator it = issues.iterator(); it.hasNext();) {
			final JiraIssue issue = (JiraIssue)it.next();
			message.append(issue.getKey());
			message.append(": ");
			message.append(issue.getSummary());
			if (it.hasNext()) {
				message.append("\n");
			}
		}

		return message.toString();
	}
}